#
# spec file for package mtr
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mtr
Version:        0.95
Release:        2.5
Summary:        Ping and Traceroute Network Diagnostic Tool
License:        GPL-2.0-only
Group:          Productivity/Networking/Diagnostic
URL:            https://www.bitwizard.nl/mtr/
Source:         https://github.com/traviscross/mtr/archive/refs/tags/v%{version}.tar.gz#/mtr-%{version}.tar.gz
Source1:        xmtr.desktop
Patch1:         mtr-0.75-manmtr.patch
Patch2:         mtr-0.87-manxmtr.patch
Patch3:         mtr-fixoverflow.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gtk3-devel
BuildRequires:  libcap-devel
BuildRequires:  libjansson-devel
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  update-desktop-files
Requires(post): permissions
Recommends:     bash-completion

%description
Mtr is a network diagnostic tool that combines Ping and Traceroute into
one program. This package contains the mtr version with an ncurses
interface, in other words, the text mode version is usable in a shell
(telnet or SSH session, for example).

Find the graphical version in the mtr-gtk package.

%package gtk
Summary:        Ping and Traceroute Network Diagnostic Tool
# needed for mtr-packet
Group:          Productivity/Networking/Diagnostic
Requires:       %{name} = %{version}
Requires:       xdg-utils

%description gtk
Mtr is a network diagnostic tool which combines Ping and Traceroute
into one program. This package contains mtr with a GTK interface.
You'll find the text mode version in the mtr package.

%prep
%setup -q
cp man/mtr.8.in man/xmtr.8.in
%autopatch -p1

%build
echo "%{version}" >.tarball-version
autoreconf -fvi

%configure \
	--disable-silent-rules \
	--enable-ipv6 \
	--with-json \
	--with-gtk \
	--disable-gtktest
%make_build
mv mtr xmtr
%make_build distclean
# console version
%configure \
	--disable-silent-rules \
	--enable-ipv6 \
	--with-json \
	--without-gtk
%make_build

%install
%make_install

# xmtr fun
install -m 4755 xmtr %{buildroot}%{_sbindir}
install -m 644 xmtr.8 %{buildroot}/%{_mandir}/man8
install -Dm 644 img/mtr_icon.xpm %{buildroot}%{_includedir}/X11/pixmaps/xmtr_icon.xpm
install -Dm 644 img/mtr_icon.xpm %{buildroot}%{_datadir}/pixmaps/xmtr_icon.xpm
%suse_update_desktop_file -i xmtr Network Monitor

%post
%set_permissions %{_sbindir}/mtr-packet

%verifyscript
%verify_permissions -e %{_sbindir}/mtr-packet

%files
%doc AUTHORS NEWS SECURITY TODO
%license COPYING
%{_datadir}/bash-completion/completions/mtr
%{_mandir}/man8/mtr-packet.8%{?ext_man}
%{_mandir}/man8/mtr.8%{?ext_man}
%verify(not caps) %attr(755,root,root) %{_sbindir}/mtr-packet
%attr(755,root,root) %{_sbindir}/mtr

%files gtk
%doc AUTHORS NEWS SECURITY TODO
%license COPYING
%{_mandir}/man8/xmtr.8%{?ext_man}
%attr(755,root,root) %{_sbindir}/xmtr
%{_includedir}/X11/pixmaps
%{_datadir}/applications/*
%{_datadir}/pixmaps/*

%changelog
* Tue Apr 11 2023 Marcus Meissner <meissner@suse.com>
- mtr-fixoverflow.patch: specify correct sizes to snprintf (bsc#1208937)
- enable json support
* Tue Jan 11 2022 Danilo Spinella <danilo.spinella@suse.com>
- update to 0.95:
  * loads of fixes,
  see https://raw.githubusercontent.com/traviscross/mtr/v0.95/NEWS
- mtr-0.75-manmtr.patch, mtr-0.87-manxmtr.patch: refreshed to apply
  again
* Tue Dec 29 2020 Dirk Müller <dmueller@suse.com>
- update to 0.94:
  * loads of fixes,
  see https://raw.githubusercontent.com/traviscross/mtr/v0.94/NEWS
- build against GTK 3
- use secure download path
- mtr-0.75-manmtr.patch, mtr-0.87-manxmtr.patch: refreshed to apply
  again
* Thu Aug 13 2020 Malte Kraus <malte.kraus@suse.com>
- Stop requiring group-membership in 'dialout' group to run mtr.
  Only run chkstat for the mtr-packet binary in %%post and %%pre
  since it's the only file that's supposed to be installed with
  capabilities (depending on security profile).
* Tue Dec 18 2018 mardnh@gmx.de
- Create file ".tarball-version" so mtr shows the proper version
  information instead of "UNKNOWN".
* Thu Nov 23 2017 ilya@ilya.pp.ua
- Add Requires/Requires(post) group(dialout) (boo#1067511).
* Mon Jul 10 2017 plinnell@opensuse.org
- Fix Requires so mtr-gtk installs properly
* Mon Jul  3 2017 tchvatal@suse.com
- Version update to mtr-0.92:
  * Loads of fixes all around see NEWS file
- Drop upstream merged patches:
  * mtr-0.75-sec_snprintf.patch
  * mtr-0.87-capabilities.patch
  * mtr-0.87-dont_copy_makefile.patch
- Refresh patch mtr-0.87-manxmtr.patch
* Thu Apr 13 2017 kstreitova@suse.com
- add mtr-0.87-dont_copy_makefile.patch in order not to overwrite
  generated Makefile with the Makefile.dist in distclean if the
  second build runs less than 3 seconds. This causes build to fail
  [bsc#1020147]
* Mon Dec 12 2016 plinnell@suse.com
- document the changed/dropped patched
- drop mtr-0.82-capabilities.patch
- add mtr-0.87-manxmtr.patch
- drop mtr-0.75-nonvoid.patch
- drop mtr-0.85-crash-with-xml-option.patch
- drop mtr-0.86-manxmtr.patch
- add mtr-0.87-capabilities.patch
* Thu Dec  8 2016 aginies@suse.com
- update to 0.87 version
- remove and adjust some patches
* Sat Jun 20 2015 lmuelle@suse.com
- update to mtr-0.86
  + Fix unnecessary runtime dependency on glib
  + Inverted IPINFO define in the code. Removes double negatives.
  + Fixed failure on IPv4 only systems when IPv6 was available at
    compile time.
  + Fixed (longstanding) bug that mtr used 100%% cpu when paused.
- rename and adapt mtr-0.75-manxmtr.patch to mtr-0.86-manxmtr.patch
* Fri Jun 12 2015 kstreitova@suse.com
- add mtr-0.85-crash-with-xml-option.patch to fix crash if '--xml'
  option is used [bnc#933854]
* Tue Sep  2 2014 kstreitova@novell.com
- cleaned up by spec-cleaner
- xmtr moved from bin to sbin and use capabilities. Fixes bnc#878729
- version bump to 0.85_p20140126:
  * snapshot taken from Gentoo
  * this works with gtk properly
- refreshed patches:
  * mtr-0.75-manxmtr.patch
  * mtr-0.82-capabilities.patch
* Tue Jul 22 2014 jengelh@inai.de
- Update to new upstream release 0.85
  * Add -z / --show-ip support
  * Made report wide switch properly to displayreport mode.
  * Fixed gtk field order. Bug #701513
  * Enable IPv6 resolvers.
- Refresh patches to clear fuzz in applying them
* Tue Jul 22 2014 meissner@suse.com
- correct mode of mtr to match "secure" permission.
- "not verify caps" to avoid patchrpm check breakage
* Wed Mar 12 2014 meissner@suse.com
- mtr-0.82-capabilities.patch: Add patch to use and drop capabilities
  instead of setuid. bnc#865351
* Fri May 25 2012 puzel@suse.com
- run_permissions macro is obsolete: use set_permissions
  (bnc#764102)
* Tue Jan 24 2012 crrodriguez@opensuse.org
- build mtr binary with PIE and full RELRO
* Wed Dec 21 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Thu Dec 15 2011 puzel@suse.com
- update to mtr-0.82
  * Enable decoding of ICMP extensions for MPLS for curses and
    report interfaces. Use the -e flag or press 'e' to enable it.
- fix spec license to GPL-2 (bnc#735559)
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Mon Oct 10 2011 puzel@suse.com
- update to mtr-0.81
  - Fix for https://bugs.launchpad.net/mtr/+bug/776211
* Mon Nov  8 2010 coolo@novell.com
- remove support for pre-9.1
* Tue Jul 20 2010 puzel@novell.com
- update to mtr-0.80
  - display load sharing hosts in --raw output
  - added about button in gui
* Sat Jan  2 2010 vuntz@opensuse.org
- Remove gtk1-compat-devel BuildRequires: it has been ported to
  GTK+ 2.x a while ago.
* Fri Nov 27 2009 mseben@novell.com
- Update patches to apply with fuzz=0
* Tue Jan  6 2009 mseben@suse.cz
- update to v0.75
  * feelgood patch to move sprintf to snprintf
  * cut-paste patches: you can now copy an intermediate host to the
    clipboard
- v0.74
  * Martin Pels' patch to allow UDP probes
  * changed some docs to advertise the new mailing list
  * added documentation for the Mac OS X compilation problem
  * added -Wno-pointer-sign to the compiler options
  * Nico Lichtmaier's cleanup-gtk patch. (now mtr uses a more modern
    dialect of gtk)
- rewritten mtr-*-sec_snprintf.patch for v0.75
* Tue May 27 2008 lmichnovic@suse.cz
- fixed more possible overflows because of using sprintf in dns.c
  (*-sec_snprintf.patch) [bnc#392458]
* Mon Apr 14 2008 lmichnovic@suse.cz
- update to version 0.73
  * Fix signed/unsigned bug in IPV6 part improved random packet
  size behaviour.
  * includes also fix for sprintf overflow [bnc#372610]
* Mon Apr  2 2007 rguenther@suse.de
- add ncurses-devel BuildRequires
* Fri Mar 30 2007 lmichnovic@suse.cz
- fixed return value for non-void function (nonvoid.patch)
* Fri Jan 12 2007 lmichnovic@suse.cz
- changed prefix /opt/gnome to /usr for aclocal
* Mon Oct  2 2006 lmichnovic@suse.cz
- update to version 0.72
  * some code improvements
  * option change: If PACKETSIZE is set to a negative number, every
  iteration will use a different, random packet size up to that
  number.
* Thu Jul 27 2006 lmichnovic@suse.cz
- building with X.org 7.x: detects version of X.org instead of
  suse_version
- uses icecream
* Mon Jul 24 2006 lmichnovic@suse.de
- udjusted specfile to build also with new X.org 7.x
* Wed Jun 14 2006 lmichnovic@suse.cz
- Upgrade to version 0.71 which obsoletes res_mkquery.diff
  - some nice improvements.
- building with gtk1-compat-devel
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 schwab@suse.de
- Don't strip binaries.
* Sun Oct  2 2005 stbinner@suse.de
- fixed GenericName in .desktop file
* Thu Jan 20 2005 postadal@suse.cz
- updated to version 0.69
- removed obsoleted patch automake.patch
* Wed Dec 15 2004 hvogel@suse.de
- fix desktop file
* Wed Nov 10 2004 ro@suse.de
- permission handling fixes for /usr/sbin/mtr
* Thu Aug 26 2004 postadal@suse.cz
- updated to version 0.65
* Thu Aug 19 2004 postadal@suse.cz
- updated to version 0.64
* Mon Aug 16 2004 postadal@suse.cz
- updated to version 0.63
- removed obsoleted patch buffer_overflow
- used gtk2
* Thu Jan 22 2004 ro@suse.de
- fixed Makefile.am
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Aug 29 2003 kukuk@suse.de
- Pack /usr/sbin/mtr with correct group
* Sat Aug 16 2003 adrian@suse.de
- add desktop file
* Mon Jul 28 2003 postadal@suse.cz
- updated to version 0.54
  * fix for raw mode
  * added "scrolling" patch from Roland Illig, to allow scrolling in text mode.
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Thu Jan 30 2003 postadal@suse.cz
- updated to version 0.52
- removed obsoleted destdir, inc , handlesig patches
* Mon Mar 18 2002 pmladek@suse.cz
- security update to fix a local buffer overflow, which enables
  an attacker to gain access to mtr's raw socket
* Mon Feb 11 2002 bk@suse.de
- updated to version 0.46(looks sane)
  * Added --address option to bind to given IP addess
- adapt configure.in check for res_mkquery to work on s390x also
- fix handling of EINTR to retry system call - fixes freeze on SIGWINCH
* Fri Jan 25 2002 pmladek@suse.cz
- updated to version 0.45:
  * added dynamic switching between numeric / dns names
  * some minor changes
* Mon Nov  5 2001 pmladek@suse.cz
- fixed to compile with automake 1.5
* Fri Jul 20 2001 pmladek@suse.cz
- updated to version 0.44
* Wed May 23 2001 pmladek@suse.cz
- fixed include files on ia64
* Mon Apr 16 2001 pmladek@suse.cz
- updated to version 0.43
- removed patch for configure.in (in new version isn't need)
- fixed compilation without GTK
* Wed Mar 28 2001 pmladek@suse.cz
- removed dependence mtr-gtk on mtr (really doesn't exist)
- added icon for xmtr to /usr/X11R6/...
* Wed Mar 14 2001 pmladek@suse.cz
- new package
- fixed configure.in (res_init)
- fixed Makefile.am (DESTDIR)
- version with and without GTK
